@@ -20,8 +20,8 @@ void GIBBS_sumpred_txt_gp(int *aggtype, double *flag, int *its, int *burnin,
 
 void GIBBS_gp(double *flag, int *its, int *burnin,
      int *n, int *T, int *r, int *rT, int *p, int *N, int *report,
-     int *cov, int *spdecay, double *shape_e, double *shape_eta,
-     double *phi_a, double *phi_b,   
+     int *cov, int *spdecay, int *ft, double *shape_e, double *shape_eta,   
+     double *phi_a, double *phi_b,
      double *prior_a, double *prior_b, double *prior_mubeta, 
      double *prior_sigbeta, double *prior_omu, double *prior_osig,
      double *phi, double *tau, double *phis, int *phik,
@@ -31,6 +31,7 @@ void GIBBS_gp(double *flag, int *its, int *burnin,
      double *sig_etapf, double *betapf, double *opf, double *zlt_mean_sd, 
      double *gof, double *penalty);
 
+/*
 void GIBBSsp_gp(int *intercept, double *flag, int *its, int *burnin,
      int *n, int *T, int *r, int *rT, int *p, int *q, int *N, int *report,
      int *cov, int *spdecay, double *shape_e, double *shape_eta, double *shape_beta,  
@@ -73,7 +74,7 @@ void GIBBSsptp_gp(int *intercept, double *flag, int *its, int *burnin,
      double *sig_etapf, double *sig_betapf, double *sig_deltapf, double *sig_0pf, double *rhopf, 
      double *betapf, double *betaspf, double *betat0pf, double *betatpf, 
      double *opf, double *zlt_mean_sd, double *gof, double *penalty);
-     
+*/     
       
 /******************** From "equation_xb_gp.c" file ***************************/
 /*****************************************************************************/
@@ -89,6 +90,7 @@ void JOINT_gp(int *n, int *T, int *r, int *rT, int *p, int *N,
      double *phip, double *accept, double *nup, double *sig_ep, double *sig_etap, 
      double *betap, double *op);
 
+/*
 void JOINTsptp_gp(int *intercept, int *n, int *T, int *r, int *rT, int *p, int *q, int *u, int *N, 
      int *cov, int *spdecay, int *rhocheck,
      double *shape_e, double *shape_eta, double *shape_beta, double *shape_del, double *shape_0,
@@ -125,17 +127,19 @@ void JOINTsp_gp(int *intercept, int *n, int *T, int *r, int *rT, int *p, int *q,
      int *constant,
      double *phip, double *accept, double *nup, double *sig_ep, double *sig_etap, 
      double *sig_betasp, double *betap, double *betasp, double *op);
+*/
           
 void sig_e_gp(int *n, int *r, int *T, int *rT, int *N, double *shape, 
      double *prior_b, double *o, double *z, int *constant, double *sig2e);
 
-void sig_e_gp_sptp(int *n, int *r, int *T, int *rT, int *N, double *shape, 
-     double *prior_b, double *o, double *z, int *constant, double *sig2e);
+//void sig_e_gp_sptp(int *n, int *r, int *T, int *rT, int *N, double *shape, 
+//     double *prior_b, double *o, double *z, int *constant, double *sig2e);
           
 void sig_eta_gp(int *n, int *r,  int *T, int *rT, double *shape, 
      double *prior_b, double *Sinv, double *XB, double *o, int *constant, 
      double *sig2eta);
 
+/*
 void sig_eta_gp_sptp(int *n, int *r,  int *T, int *rT, double *shape, 
      double *prior_b, double *Sinv, double *XB, double *o, int *constant, 
      double *sig2eta);
@@ -156,39 +160,41 @@ void beta_gp_tp(int *n, int *r, int *T, int *rT, int *u, double *sig0,
      
 void rho_gp_tp(int *u, int *T, double *prior_mu, double *prior_sig, 
      double *sigdelta, double *gam0, double *gamma, int *constant, double *rhop);
+*/
                          
 void beta_gp(int *n, int *r, int *T, int *rT, int *p, double *prior_mu,
      double *prior_sig, double *Qeta, double *X, double *o, int *constant, 
      double *betap);
-     
+
+/*     
 void beta_gp_for_sp(int *n, int *r, int *T, int *rT, int *p, double *prior_mu,
      double *prior_sig, double *Qeta, double *X, double *XBsp, double *o, 
      int *constant, double *betap); 
 void beta_gp_for_sptp(int *n, int *r, int *T, int *rT, int *p, double *prior_mu,
      double *prior_sig, double *Qeta, double *X, double *XBsp, double *XBtp, 
      double *o, int *constant, double *betap);
-
 void beta_gp_sp(int *n, int *r, int *T, int *rT, int *q, int *N, double *prior_mu,
      double *prior_sig2betasp, double *betas, double *Qeta, double *Sinv, 
      double *Xsp, double *XB, double *o, int *constant, double *betap); 
+*/
      
 void o_gp(int *n, int *r, int *T, int *rT, double *prior_omu,
      double *prior_osig, double *sig_e, double *sig_eta, double *S, 
      double *Qeta, double *XB, double *z, int *constant, double *opost);
 
-void o_gp_sptp(int *n, int *r, int *T, int *rT, double *prior_omu,
-     double *prior_osig, double *sig_e, double *sig_eta, double *S, 
-     double *Qeta, double *XB, double *z, int *constant, double *opost);
+//void o_gp_sptp(int *n, int *r, int *T, int *rT, double *prior_omu,
+//     double *prior_osig, double *sig_e, double *sig_eta, double *S, 
+//     double *Qeta, double *XB, double *z, int *constant, double *opost);
           
 void phi_gp_MH(double *Qeta1, double *Qeta2, double *det1, double *det2,
      double *phi1, double *phi2, int *n, int *r, int *T, int *rT, int *N, 
      double *prior_a, double *prior_b, double *XB, double *o, int *constant, 
      double *accept, double *phip);
 
-void phi_gp_MH_sptp(double *Qeta1, double *Qeta2, double *det1, double *det2,
-     double *phi1, double *phi2, int *n, int *r, int *T, int *rT, int *N, 
-     double *prior_a, double *prior_b, double *XB, double *o, int *constant, 
-     double *accept, double *phip);
+//void phi_gp_MH_sptp(double *Qeta1, double *Qeta2, double *det1, double *det2,
+//     double *phi1, double *phi2, int *n, int *r, int *T, int *rT, int *N, 
+//     double *prior_a, double *prior_b, double *XB, double *o, int *constant, 
+//     double *accept, double *phip);
           
 void phi_gp_DIS(int *cov, double *Qeta1, double *det1, double *phi1,  
      double *phis, int *phik, double *nu, int *n, int *r, int *T, int *rT, int *N, 
@@ -200,6 +206,7 @@ void phidens_gp(double *phi, double *Qeta, double *det, int *n, int *r,
      int *T, int *rT, int *N, double *prior_a, double *prior_b, double *XB, 
      double *o, int *constant, double *out);
 
+/*
 void phi_gp_DIS_sptp(int *cov, double *Qeta1, double *det1, double *phi1,  
      double *phis, int *phik, double *nu, int *n, int *r, int *T, int *rT, int *N, 
      double *prior_a, double *prior_b, double *d,
@@ -209,6 +216,7 @@ void phi_gp_DIS_sptp(int *cov, double *Qeta1, double *det1, double *phi1,
 void phidens_gp_sptp(double *phi, double *Qeta, double *det, int *n, int *r, 
      int *T, int *rT, int *N, double *prior_a, double *prior_b, double *XB, 
      double *o, int *constant, double *out);
+*/
      
 void nu_gp_DIS(int *cov, double *Qeta1, double *det1, double *phi,  
      double *nu1, int *n, int *r, int *T, int *rT, int *N, 
@@ -218,13 +226,14 @@ void nu_gp_DIS(int *cov, double *Qeta1, double *det1, double *phi,
 void nudens_gp(double *Qeta, double *det, int *n, int *r, int *T, int *rT, 
      int *N, double *XB, double *o, int *constant, double *out);
 
+/*	 
 void nu_gp_DIS_sptp(int *cov, double *Qeta1, double *det1, double *phi,  
      double *nu1, int *n, int *r, int *T, int *rT, int *N, 
      double *d,  double *sig2eta, double *XB, double *o, int *constant, 
      double *nup);
-     
 void nudens_gp_sptp(double *Qeta, double *det, int *n, int *r, int *T, int *rT, 
      int *N, double *XB, double *o, int *constant, double *out);
+*/
      
 /******************** From "prediction_xb_gp.c" file ***************************/
 /*****************************************************************************/
@@ -239,33 +248,30 @@ void z_pr_gp(int *cov, int *nsite, int *n, int *r, int *rT, int *T, int *p,
      int *N, int *valN, double *d, double *d12, double *phip, double *nup, 
      double *sig_ep, double *sig_etap, double *betap, double *X, double *valX,
      double *op, int *constant, double *zpred);
-     
+	 
+/*     
 void z_pr_its_gp_sp(int *cov, int *its, int *nsite, int *n, int *r, int *rT, 
      int *T, int *p, int *q, int *N, int *valN, double *d, double *d12, 
      double *phip, double *nup, double *sig_ep, double *sig_etap, double *sig_betap,
      double *betap, double *betasp, double *X, double *valX, double *Xsp, 
      double *valXsp, double *op, int *constant, double *betapred, double *zpred);
-
 void z_pr_gp_sp(int *cov, int *nsite, int *n, int *r, int *rT, int *T, int *p, 
      int *q, int *N, int *valN, double *d, double *d12, double *phip, double *nup, 
      double *sig_ep, double *sig_etap, double *sig_betap, double *betap, double *betasp, 
      double *X, double *valX, double *Xsp, double *valXsp,
      double *op, int *constant, double *betapred, double *zpred);
-
 void z_pr_its_gp_tp(int *cov, int *its, int *nsite, int *n, int *r, int *rT, 
      int *T, int *p, int *u, int *N, int *valN, double *d, double *d12, 
      double *phip, double *nup, double *sig_ep, double *sig_etap, double *sig_deltap,
      double *sig_op, double *betap, double *rhotp, double *betat0p, double *betatp,  
      double *X, double *valX, double *Xtp, double *valXtp, double *op, 
      int *constant, double *zpred);
-     
 void z_pr_gp_tp(int *cov, int *nsite, int *n, int *r, int *rT, int *T, int *p, 
      int *u, int *N, int *valN, double *d, double *d12, double *phip, double *nup, 
      double *sig_ep, double *sig_etap, double *sig_deltap, double *sig_op,
      double *betap, double *rhotp, double *betat0p, double *betatp, double *X, 
      double *valX, double *Xtp, double *valXtp, double *op, int *constant, 
      double *zpred);
-
 void z_pr_its_gp_sptp(int *cov, int *its, int *nsite, int *n, int *r, int *rT, 
      int *T, int *p, int *q, int *u, int *N, int *valN, double *d, double *d12, 
      double *phip, double *nup, double *sig_ep, double *sig_etap, double *sig_betap,
@@ -273,7 +279,6 @@ void z_pr_its_gp_sptp(int *cov, int *its, int *nsite, int *n, int *r, int *rT,
      double *rhotp, double *betat0p, double *betatp, double *X, double *valX, 
      double *Xsp, double *valXsp, double *Xtp, double *valXtp, double *op, 
      int *constant, double *betapred, double *zpred);
-
 void z_pr_gp_sptp(int *cov, int *nsite, int *n, int *r, int *rT, int *T, int *p, 
      int *q, int *u, int *N, int *valN, double *d, double *d12, double *phip, 
      double *nup, double *sig_ep, double *sig_etap, double *sig_betap, 
@@ -281,6 +286,7 @@ void z_pr_gp_sptp(int *cov, int *nsite, int *n, int *r, int *rT, int *T, int *p,
      double *rhotp, double *betat0p, double *betatp, double *X, double *valX, 
      double *Xsp, double *valXsp, double *Xtp, double *valXtp, double *op, 
      int *constant, double *betapred, double *zpred);
+*/
      
 /******************** From "forecast_xb_gp.c" file ***************************/
 /*****************************************************************************/
@@ -294,7 +300,8 @@ void zlt_fore_gp(int *cov, int *K, int *nsite, int *n, int *r, int *p,
      int *rT, int *T, int *rK, int *nrK, double *d, double *d12, 
      double *phi, double *nu, double *sig_e, double *sig_eta, double *foreX, 
      double *beta, double *w, int *constant, double *foreZ);
-
+	 
+/*
 void zlt_fore_gp_sp_its(int *cov, int *its, int *K, int *nsite, int *n, int *r, 
      int *p, int *q, int *rT, int *T, int *rK, int *nrK, double *d, double *d12,
      double *phip, double *nup, double *sig_ep, double *sig_etap, double *sig_betap,
@@ -332,6 +339,7 @@ void zlt_fore_gp_sptp(int *cov, int *K, int *nsite, int *n, int *r, int *p,
      double *sig_delta, double *sig_op, double *foreX, double *foreXsp, 
      double *foreXtp, double *beta, double *betas, double *rhotp, double *betat0, 
      double *betat, double *w, int *constant, double *foreZ);
+*/
           
 /*****************************************************************************/
      
